# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class SkillContentResult(UniversalBaseModel):
    name: str = pydantic.Field()
    """
    Skill name
    """

    path: str = pydantic.Field()
    """
    Absolute path to the skill directory
    """

    content: str = pydantic.Field()
    """
    Skill content excluding front matter
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
